////////////////////////////////////////////////////////////////////////////////
//
// Project:     TUCP.DLL
//
// Filename:    tucp.h
//
// Purpose:     Define and document interfaces for use with the Timex USB Data Link
//              packaging DLL.
//
// History:     2002-01-21  ALB
//
// Notes:
//
////////////////////////////////////////////////////////////////////////////////

#ifndef __TUCP_H__
#define __TUCP_H__

#define EXPORT32  __declspec(dllexport)

// List of device types for use with TUDLSetDeviceType()
#define DL_DEV_851                          1       // Ironman USB Data Link Watch

#define TIMER_INTERVAL 20

// Error codes returned form TUDLGetOption() API with DL_OPT_SYS_ERR_CODE identifier
#define TIMEX_SUCCESS                       0       // No error

//#define TIMEX_ERR_GENERAL                   1       // general error occured

#define TIMEX_ERR_TOO_MUCH_DATA             3       // Attempt to add too much data

#define TIMEX_ERR_NO_MEM                    4       // Malloc failed

//#define TIMEX_ERR_USER_ABORT                5       // User aborted send

#define TIMEX_ERR_FILE_ERR                  7       // Error creating temp file

#define TIMEX_ERR_INV_PACKET_LEN            8       // Invalid packet length

#define TIMEX_ERR_INV_PARM                  9       // API parameter invalid

#define TIMEX_ERR_DEV_NOT_FOUND             10      // Device not found

#define TIMEX_ERR_COMM                      11      // Generic communication error occurred

#define TIMEX_ERR_COMM_CHECKSUM             12      // Checksum communication error occurred

#define TIMEX_ERR_COMM_PACKET_LEN           13      // Invalid packet length communication error occurred

#define TIMEX_ERR_COMM_DEV_INFO             14      // Device info request communication error occurred

#define TIMEX_ERR_COMM_DEV_MISMATCH         15      // Device mismatch communication error occurred

#define TIMEX_ERR_COMM_TIMEOUT              16      // Packet timeout communication error occurred

//#define TIMEX_ERR_INV_RESOURCE              17      // Packet timeout communication error occurred

#define TIMEX_ERR_NO_ITEM                   18      // There are no more entries for the given application
                                                    // type, application instance, and/or item type
#define TIMEX_READ_FILE_TIMEOUT				19		// This occurs when the ReadFile API function has a timeoout


#define TIMEX_ERR_DEV_API_MISMATCH          27      // Unsupported API for selected device class
                                                    // This error occurs when the selected devices
                                                    // do not support programs, melodies, system data or
                                                    // international date formats but an attempt is made to
                                                    // set this info; determining device support is as follows:
                                                    // Support for downloadable programs is determined by using
                                                    // the TUDLGetOption API with the DL_DEV_SUP_PROGRAM
                                                    // identifier.
                                                    // Support for downloadable melodies is determined by using
                                                    // the TUDLGetOption API with the DL_DEV_SUP_MELODY
                                                    // identifier.
                                                    // Support for system data is determined by using the
                                                    // TUDLGetOption API with the DL_DEV_SUP_SYSTEM_DATA
                                                    // identifier.
                                                    // Support for international date formats is determined by
                                                    // using the TUDLGetOption API with the
                                                    // DL_DEV_SUP_INTL_DATE_FORMATS identifier.

#define TIMEX_ERR_PROG_EXISTS               30      // Tried to add a program, but one already exists.
                                                    // If downloadable programs are supported, all devices
                                                    // at the time of this writing only support a single
                                                    // instance of them.


#define TIMEX_ERR_ITEM_EXISTS               32      // Tried to add an item but it already exitst and 
                                                    // one already exists.

#define TIMEX_ERR_BAD_CHAR_IN_PROG          33      // Char found which wasn't 0-9,A-F,a-f

#define TIMEX_ERR_INVALID_DEVICE            34      // Device type tested to be invalid



#define TIMEX_ERR_PROGRAM_TOO_LARGE         46      // The front-end attempted to add a program
                                                    // larger than the receiver's downloadable
                                                    // program region.

#define TIMEX_ERR_MELODY_TOO_LARGE          47      // The front-end attempted to add a melody
                                                    // larger than the receiver's downloadable
                                                    // melody region.

#define TIMEX_ERR_TOO_MUCH_BINARY_DATA      48      // The front-end attempted to add more
                                                    // binary data than can be transmitted.

#define TIMEX_ERR_COMM_LOST_SUSPEND_MODE    49      // The PC went into suspend mode, so communication
                                                    // was terminated.

#define TIMEX_WRN_OVER_MAXDATA              -1      // Added more data than wMaxData

#define TIMEX_WRN_TEXT_TRUNCATED            -2      // Text string truncated

#define TIMEX_WRN_CHAR_LOST                 -3      // Untranslateable character

#define TIMEX_WRN_NO_DATA                   -5      // No data to transmit

#define TIMEX_WRN_DEFAULT_DEV_SET           -6      // Error while processing ini file
                                                    // so set device type to the default

#define TIMEX_WRN_USER_ABORT                -8      // User aborted send

#define TIMEX_WRN_TOO_MANY_RECORDS          -9      // Number of records added has exceeded
                                                    // the amount supported by device

#define TIMEX_WRN_NUMBER_ADJUSTED			-10     // Number has been adjusted to the closest
                                                    // amount supported by device

#define TIMEX_WRN_NOT_LAST_DEVICE			-11		// We tried to communicate with the device, but it wasn't
													// the same one we talked to last time

// Options for TUDLGetOption and TUDLSetOption API functions.
//
// "DL_OPT_SYS_" and "DL_OPT_DEV_" identifiers typically can only be
// used with the TUDLGetOption API function (that is, the settings
// accessed by these identifiers are effectively read-only values).
// "DL_OPT_OUT_" identifiers typically can be used with both API
// functions (that is, the settings accessed by these identifiers are
// effectively read-write values).


#define DL_OPT_DEV_APPT_LEN                 1       // Returns max allowable length of appointment
                                                    // messages for the selected device.
                                                    // This is typically 100 characters.

#define DL_OPT_DEV_NOTE_LEN                 2       // Returns max allowable length of note item 
                                                    // messages for the selected receiver / device.

#define DL_OPT_DEV_PHONE_LEN                3       // Returns max allowable length of phone
                                                    // messages (name) for the selected receiver / device. 

#define DL_OPT_DEV_PHONE_NUM_LEN            4       // Returns max allowable length of phone book 
                                                    // numbers for the selected receiver / device.
                                                    // This is typically 12 characters.

#define DL_OPT_DEV_OCC_LEN                  5       // Returns max allowable length of occasion
                                                    // messages for the selected receiver / device.

#define DL_OPT_DEV_ALARM_LEN                6       // Returns max allowable length of alarm
                                                    // messages for the selected receiver / device.

#define DL_OPT_DEV_CITY_LEN                 7       // Returns max allowable length of city code
                                                    // messages for the selected receiver / device.
                                                    // This is typically 3 characters.
                                                    // "PST" is an example of an alarm message.

#define DL_OPT_DEV_MAX_PACKET_LEN           8       // Returns max allowable packet length for
                                                    // the selected receiver / device.
                                                    // This ID is for internal use only, and
                                                    // should not be used by application
                                                    // developers.

#define DL_OPT_DEV_TOD_MAX                  9       // Returns max number of Time Of Day zones supported by
                                                    // the selected device

#define DL_OPT_SYS_DEVICE                   10      // Returns the currently-selected device type.
                                                    // For example, DL_DEV_851
                                                    //
                                                    // Use the SetDeviceType() API to set a new device type.

                                                    //
#define DL_OPT_DEV_MAX_DATABASE             12      // Returns the max size of database information for
                                                    // the selected receiver / device.
                                                    //
                                                    // The database consists of all application entries.
                                                    // The database is a single block
                                                    // in most devices; this means that these
                                                    // info types are combined into a single
                                                    // structure, which is downloaded as a unit.
                                                    // It is therefore impossible to update a
                                                    // device's phonebook yet leave the appointments
                                                    // unaffected.
                                                    //
                                                    // A PIM / front-end app can typically accept
                                                    // more information than can be stored in a device.
                                                    // This ID is therefore used to control the amount
                                                    // of database data to be downloaded.  This is
                                                    // accomplished by adding all the database,
                                                    // request the max allowable database size using
                                                    // this ID, then request the current total database
                                                    // size using the DL_OPT_DEV_TOTAL_DATA identifier
                                                    // (described next).  A warning should be displayed
                                                    // once the total exceeds the max, and actual
                                                    // download must be inhibited until the total is
                                                    // less than or equal to the max allowable.
                                                    
#define DL_OPT_DEV_TOTAL_DATA               13      // Returns the current size of the database information
                                                    // structure for the selected receiver / device.
                                                    //
                                                    // This value may exceed the maximum allowable database
                                                    // size for the selected device.  It is therefore required
                                                    // that this value be compared to the value returned using
                                                    // the DL_OPT_DEV_MAX_DATABASE identified (described above).
                                                    // The actual download must be inhibited until the current
                                                    // database structure size is less or equal to the max
                                                    // allowable.

#define DL_OPT_DEV_TOTAL_USER_MEMORY        14      // Returns a value specifying percentage of the memory 
                                                    // used by currently selected data for the current device.
                                                    //
                                                    // This parameter can be used in place of the previous two
                                                    // to show the percentage of memory used.

#define DL_OPT_DEV_MAX_APPS                 15      // Returns a value specifying the maximum number of
													// applications (modes). Time of day mode and communication
													// mode are excluded from this value.




#define DL_OPT_DEV_MAX_PROGRAM              27      // Returns the max size of downloadable program area for
                                                    // the selected receiver / device.
                                                    //
                                                    // Downloadable programs are small programs which can be 
                                                    // downloaded to the device using Timex Data Link.
                                                    //
                                                    // The value returned is the memory size allocated by
                                                    // the device to store the downloadable program (in bytes).
                                                    //
                                                    // Use the DL_DEV_SUP_PROGRAM identifier with
                                                    // TUDLGetOption to determine if the selected
                                                    // device supports downloadable programs.

#define DL_OPT_DEV_MAX_MELODY               28      // Returns the max size of downloadable melody area
                                                    // for the selected receiver / device.
                                                    //
                                                    // Downloadable melodies are small sound-scapes
                                                    // which can be downloaded to the device using Timex Data
                                                    // Link.
                                                    //
                                                    // The value returned is the memory size allocated by
                                                    // the device to store the downloadable melody (in bytes).
                                                    //
                                                    // Use the DL_DEV_SUP_MELODY identifier with
                                                    // TUDLGetOption to determine if the selected
                                                    // device supports downloadable melody info.


#define DL_OPT_DEV_TIMER_MAX                29      // Returns max number of timer entries supported by
                                                    // the selected receiver

#define DL_OPT_DEV_INTTIMER_MAX             30      // Returns max number of interval timer entries
                                                    // supported by the selected receiver

#define DL_OPT_DEV_SCHEDULE_MAX             31      // Returns max number of schedule entries
                                                    // supported by the selected receiver

#define DL_OPT_DEV_SCHEDULE_GROUP_MAX       32      // Returns max number of schedule groups
                                                    // supported by the selected receiver

#define DL_OPT_DEV_SCHEDULE_GROUP_NAME_LEN  33      // Returns max length of the group name
                                                    // This is a label for the schedule mode set position
                                                    // such as "LOCATION" or "TEAM"

#define DL_OPT_DEV_SCHEDULE_NUM             34      // Returns current number of schedule entries

#define DL_OPT_DEV_INTTIMER_NUM             35      // Returns current number of interval timer

#define DL_OPT_DEV_TIMER_NUM                36      // Returns current number of timer

#define DL_OPT_DEV_ALARM_NUM                37      // Returns current number of alarms

#define DL_OPT_SYS_ERR_CODE                 38      // Returns the specific error code for the most recent
                                                    // API call.
                                                    //
                                                    // With few exceptions, all API functions return a value
                                                    // of 0 for success, a value less than 0 for an error
                                                    // and a value greater than 0 for a warning.  Most often,
                                                    // it is sufficient to simply test the return value and
                                                    // if an error then cancel current operation and shut-down,
                                                    // and if a warning then just continue on knowing that a
                                                    // non-critical error occurred.


#define DL_OPT_DEV_SUP_PROGRAM              45      // Returns a boolean value indicating the support for
                                                    // downloadable programs for the selected receiver / device.
                                                    //
                                                    // Downloadable programs are small programs which can be 
                                                    // downloaded to the device using Timex Data Link.
                                                    //
                                                    // Because front-end support of downloadable programs
                                                    // is under development, please contact Timex to
                                                    // obtain more technical detail than can be included
                                                    // here.

#define DL_OPT_DEV_SUP_MELODY               46      // Returns a boolean value indicating the support for
                                                    // downloadable melody information for the selected
                                                    // receiver / device.
                                                    //
                                                    // Downloadable melodies are small sound-scapes
                                                    // which can be downloaded to the device using Timex Data
                                                    // Link.
                                                    //
                                                    // Because front-end support of downloadable 
                                                    // melodies is under development, please contact Timex
                                                    // to obtain more technical detail than can be included
                                                    // here.

#define DL_OPT_DEV_SUP_SYSTEM_DATA          47      // Returns a boolean value indicating the support for
                                                    // downloadable system information for the selected
                                                    // receiver / device.
                                                    //
                                                    // System information consists of settings such as
                                                    // hourly chime control and keypress beeps on the
                                                    // device.

#define DL_OPT_DEV_SUP_INTL_DATE_FORMAT     48      // Returns a boolean value indicating the support for
                                                    // international date formats for the selected
                                                    // receiver / device.
                                                    //
                                                    // International date formats allow the device to display
                                                    // date information in MMDDYY, YYMMDD and DDMMYY ordering,
                                                    // using "." or "-" characters as seperators.

#define DL_OPT_SYS_NUM_DEVICES              49      // Returns the number of device types
                                                    // the system is aware of.

#define DL_OPT_DEV_APPT_NUM                 50      // Returns current number of appointments

#define DL_OPT_DEV_NOTE_NUM                 51      // Returns current number of note entries

#define DL_OPT_DEV_PHONE_NUM                52      // Returns current number of phone numbers
                                         
#define DL_OPT_DEV_OCC_NUM                  53      // Returns current number of anniversaries

#define DL_OPT_DEV_ALARM_MAX                54      // Returns max number of alarms supported by the device

#define DL_OPT_DEV_APPT_MAX                 55      // Returns max number of appointments supported by
                                                    // the selected receiver / device.

#define DL_OPT_DEV_NOTE_MAX                 56      // Returns max number of note entries supported by
                                                    // the selected receiver / device.

#define DL_OPT_DEV_PHONE_MAX                57      // Returns max number of phone numbers supported by
                                                    // the selected receiver / device.

#define DL_OPT_DEV_OCC_MAX                  58      // Returns max number of occasions supported by
                                                    // the selected receiver / device.

#define DL_OPT_DEV_TIMER_LEN                60      // Returns max allowable length of timer
                                                    // messages for the selected receiver / device.
                                                    // This is typically 8 characters.
                                                    // "Boil Egg" is an example of an timer message.

#define DL_OPT_DEV_CHRONO_NAME_LEN          61      // Returns max allowable length of chrono name.

#define DL_OPT_DEV_CHRONO_NUM               62      // Returns or sets current number of chrono laps.

#define DL_OPT_DEV_CHRONO_MAX               63      // Returns max allowable number of chrono laps.

#define DL_OPT_DEV_SUP_CHRONO               64      // Returns a boolean value indicating the support
                                                    // for configurable/controllable chronographs for
                                                    // the selected receiver / device.
                                                    //
                                                    // Controllable chronos allow a user to configure
                                                    // the chrono embedded in the receiver.  Options
                                                    // such as number of laps of storage are set.

#define DL_OPT_DEV_SUP_TIMER                65      // Returns a boolean value indicating the support
                                                    // for configurable/controllable timers for
                                                    // the selected receiver / device.
                                                    //
                                                    // Controllable timers allow a user to configure
                                                    // the timer embedded in the receiver.  Options
                                                    // such as timeout duration are set.

#define DL_OPT_DEV_SUP_BINARY_DATA          66      // Returns a boolean value indicating the support
                                                    // for downloadable binary data to the selected
                                                    // receiver / device.
                                                    //
                                                    // Downloadable binary data is device-specific
                                                    // information formatted according to a Timex
                                                    // download specification and a receiver-specific
                                                    // data format specification.

#define DL_OPT_DEV_MAX_BINARY_DATA          67      // Returns the max size of binary data area for
                                                    // the selected receiver / device.
                                                    //
                                                    // Downloadable binary data is device-specific
                                                    // information formatted according to a Timex
                                                    // download specification and a receiver-specific
                                                    // data format specification.
                                                    //
                                                    // The value returned is the memory size allocated by
                                                    // the device to store the binary data (in bytes).
                                                    //
                                                    // Use the DL_DEV_SUP_BINARY_DATA identifier with
                                                    // TUDLGetOption to determine if the selected
                                                    // device supports binary data downloads.

#define DL_OPT_DEV_SUP_DATABASE             68      // Returns a boolean value indicating the support
                                                    // for any or all the database types (appointments,
                                                    // anniversaries, phone books and to-do lists)
                                                    // for the selected receiver / device.
                                                    //
                                                    // Databases allow storage of the 4 information
                                                    // types outlined above.  Most devices will
                                                    // support all the database types, but some will
                                                    // only support a subset of the database types.

#define DL_OPT_DEV_CHRONO_MIN               71      // Returns min allowable number of chrono laps.

#define DL_OPT_DEV_CHRONO_FORMAT            72      // Sets or returns chrono display format which can
                                                    // be one of the ChronoFormat enum types


#define DL_OPT_DEV_SUP_NIGHTMODE_OPT        73      // Returns a boolean value indicating the support
                                                    // for setting Night-Mode options.

////////////////////////////////////////////////////////////////////////////////
// 
// This section describes the structures used to pass information on the
// AddItem() API calls.
// 
////////////////////////////////////////////////////////////////////////////////

// These are currently supported application/item types; their definitions follow below
enum AppIndex
{
    TOD_APP      = 0,
	COMM_APP     = 1,
    CHRONO_APP   = 2,
    TIMER_APP    = 3,
    INTTIMER_APP = 4,
    ALARM_APP    = 5,
    APPT_APP     = 6,
    NOTE_APP     = 7,
    OPTION_APP   = 8,
    OCCASION_APP = 9,
    CONTACT_APP  = 10,
    SCHEDULE_APP = 11,
	SYNCHRO_APP  = 12,
	COUNTER_APP  = 13,
	SOUND_APP    = 16,
    WRISTAPP_APP = 17
};

// Time Of Day equates and item struct
enum DateFormat 
{
	DMY = 0, // dd.mm.yy
	YMD = 1, // yy-mm-dd
	MDY = 2  // mm-dd-yy
};

enum TimeFormat
{
	HOUR12 = 0, // am/pm time
	HOUR24 = 1  // everybody else's time
};

enum TimeZoneIndex
{
    TZ_GMT = 0,
    TZ_1 = 1       // use pager time zones here
};

typedef struct _TOD_ITEM
{
    BYTE bItemID;            // zero-based time zone index, 0=primary time, must be unique for each time zone
    LPTSTR  pszText;         // pointer to a null-terminated string containing city code abbreviation
    int  cchTextMax;         // number of characters in the buffer pointed to by pszText
    LONG lTimeOffset;        // time offset to the current system time (UTC) in seconds
	BYTE bTimeZoneID;		 // used to calculate the time offset parameters for World Time
    TimeZoneIndex nTZIndex;  // index of the time zone
    DateFormat nDateFormat;  // date format according to the date format enumaration
    TimeFormat nTimeFormat;  // time format according to the time format enumaration
    BOOL boolDSTObserved;    // does the time zone observe daylight saving time
    BOOL boolIsInDST;        // is the time zone currently in the daylight saving time
    BOOL boolShowWeekNumber; // show week number in place of day of week
    BYTE b1stDayOfWeek;      // 0=Sun, 1=Mon
    DWORD dwReserved;        // reserved for future use
} TOD_ITEM, *LPTOD_ITEM;


// Chrono enumerations and item struct
enum ChronoFormat
{
    CHRONOFORMAT_LAP_SPLIT  = 0,
    CHRONOFORMAT_SPLIT_LAP  = 1,
    CHRONOFORMAT_TIME_SPLIT = 2,
    CHRONOFORMAT_TIME_LAP   = 3
};

typedef struct _CHRONO_ITEM
{
    WORD wItemID;            // must be a unique index of the item to which this structure refers
    WORD wWorkoutID;         // must be a unique index of the workout to which this structure refers
    BYTE bType;              // 0=unused, 1=workout, 2=lap
    // workout data
    BYTE bNumLaps;           // number of laps in the workout
    DATE dtDateTime;         // the date and time of the workout
    // lap data
    BYTE bLapNum;            // lap number
    BYTE bHour;              // lap hour
    BYTE bMinute;            // lap minute
    BYTE bSecond;            // lap second
    BYTE bHundredth;         // lap hundredth of a second
	BYTE bModified;			 // modified or not
} CHRONO_ITEM, *LPCHRONO_ITEM;


// Timer enumerations and item struct
enum TimerAction
{
    TIMERACTION_STOP   = 0,
    TIMERACTION_REPEAT = 1,
    TIMERACTION_CHRONO = 2
};

typedef struct _TIMER_ITEM
{
    WORD wItemID;            // must be a unique index of the item to which this structure refers
    LPTSTR  pszText;         // pointer to a null-terminated string that contains the item text, 9 chars max
    int  cchTextMax;         // number of characters in the buffer pointed to by pszText
    BYTE bHour;              // timer hour 0-23
    BYTE bMinute;            // timer minute 0-59
    BYTE bSecond;            // timer second 0-59
    TimerAction nAction;     // action at end of timer
    BYTE bNumOfReps;         // number of repetitions
    BYTE bOptions;           // timer options: 0=half-way reminder not set, 1=reminder set
} TIMER_ITEM, *LPTIMER_ITEM;


// schedule enumerations and item struct
enum ScheduleType
{
    SCHEDULE_DATE      = 1,
    SCHEDULE_DOW_TIME  = 2,
	SCHEDULE_DATETIME  = 3 
};

typedef struct _SCHEDULE_ITEM
{
    WORD wGroupID;           // must be a unique index of the group to which this structure refers
    LPTSTR  pszGroupText;    // pointer to a null-terminated string that contains the group text
    int  cchGroupTextMax;    // number of characters in the buffer pointed to by pszGroupText
    LPTSTR  pszGroupLabel;   // pointer to a null-terminated string that contains the group label
    int  cchGroupLabelMax;   // number of characters in the buffer pointed to by pszGroupLabel
    ScheduleType nType;      // schedule type according to the enum
    WORD wItemID;            // must be a unique index of the item to which this structure refers
    LPTSTR  pszText;         // pointer to a null-terminated string that contains the item text
    int  cchTextMax;         // number of characters in the buffer pointed to by pszText
    DATE dtDateTime;         // the date and time of the schedule item
    int nDayOfWeek;          // day of the week for schedule type DOW_TIME; 0=sun, 1=mon,... 6=sat
} SCHEDULE_ITEM, *LPSCHEDULE_ITEM;

typedef struct _SCHEDULE_IMPORT_ITEM
{
    WORD wGroupID;           // Should be 0 for imports
	LPTSTR  pszScheduleName; // pointer to a null-terminated string that contains the schedule name
	int  cchScheduleNameMax; // number of characters in the buffer pointed to by pszScheduleName
    LPTSTR  pszGroupText;    // pointer to a null-terminated string that contains the group text
    int  cchGroupTextMax;    // number of characters in the buffer pointed to by pszGroupText
    LPTSTR  pszGroupLabel;   // pointer to a null-terminated string that contains the group label
    int  cchGroupLabelMax;   // number of characters in the buffer pointed to by pszGroupLabel
    ScheduleType nType;      // schedule type according to the enum
    WORD wItemID;            // must be a unique index of the item to which this structure refers
    LPTSTR  pszText;         // pointer to a null-terminated string that contains the item text
    int  cchTextMax;         // number of characters in the buffer pointed to by pszText
    DATE dtDateTime;         // the date and time of the schedule item
    int nDayOfWeek;          // day of the week for schedule type DOW_TIME; 0=sun, 1=mon,... 6=sat
} SCHEDULE_IMPORT_ITEM, *LPSCHEDULE_IMPORT_ITEM;

// alarm enumerations and item struct
enum AlarmStatus
{
	ALM_UNUSED   = 0, 
    ALM_DISARMED = 1,
    ALM_ARMED    = 3
};

enum AlarmFrequency
{
	ALMFREQ_DAILY     = 1, 
    ALMFREQ_WEEKDAY   = 2,
    ALMFREQ_WEEKEND   = 3,
    ALMFREQ_WEEKLY_SU = 4,
    ALMFREQ_WEEKLY_MO = 5,
    ALMFREQ_WEEKLY_TU = 6,
    ALMFREQ_WEEKLY_WE = 7,
    ALMFREQ_WEEKLY_TH = 8,
    ALMFREQ_WEEKLY_FR = 9,
    ALMFREQ_WEEKLY_SA = 10
};

typedef struct _ALARM_ITEM
{
    WORD wItemID;            // must be a unique index of the item to which this structure refers
    LPTSTR  pszText;         // pointer to a null-terminated string that contains the item text
    int  cchTextMax;         // number of characters in the buffer pointed to by pszText
    AlarmStatus nStatus;     // alarm status: 0=unused, 1=used/disarmed, 3=used/armed
    AlarmFrequency nFreq;    // frequency (or occurence) of the alarm
	BYTE bHour;              // alarm hour
	BYTE bMinute;            // alarm minute
    DATE dtReserved1;        // not used
	BYTE bModified;			 // modified or not
} ALARM_ITEM, *LPALARM_ITEM;


// Appointment enumerations and item struct
enum ApptStatus
{
	APPT_UNUSED   = 0, 
    APPT_DISARMED = 1,
    APPT_ARMED    = 3
};

enum Frequency
{
	APPTFREQ_1DAY    = 0, // 1-day (one-time) occurance
	APPTFREQ_DAILY   = 1, 
    APPTFREQ_WEEKDAY = 2,
    APPTFREQ_WEEKEND = 3,
    APPTFREQ_WEEKLY  = 11,
    APPTFREQ_MONTHLY = 12,
    APPTFREQ_YEARLY  = 13
};

enum Reminder
{
	REMINDER_0MINS  = 0,
	REMINDER_5MINS  = 1,
	REMINDER_10MINS = 2,
	REMINDER_15MINS = 3,
	REMINDER_30MINS = 4,
	REMINDER_60MINS = 5,
	REMINDER_2HRS   = 6,
	REMINDER_3HRS   = 7,
	REMINDER_4HRS   = 8,
	REMINDER_5HRS   = 9,
	REMINDER_6HRS   = 10,
	REMINDER_8HRS   = 11,
	REMINDER_10HRS  = 12,
	REMINDER_12HRS  = 13,
	REMINDER_24HRS  = 14,
	REMINDER_48HRS  = 15
};

typedef struct _APPT_ITEM
{
    WORD wItemID;            // must be a unique index of the item to which this structure refers
    LPTSTR  pszText;         // pointer to a null-terminated string that contains the item text
    int  cchTextMax;         // number of characters in the buffer pointed to by pszText
    DATE dtStartDateTime;    // the date and time of the first occurrence of the appt
    ApptStatus nStatus;      // appointment status: 0=unused, 1=disarmed, 3=armed
    Frequency nFreq;         // frequency (or occurence) of the appt
    Reminder nReminder;      // reminder offset (used to calculate prenotification time)
    DATE dtReserved1;        // not used
    DATE dtReserved2;        // not used
	BYTE bModified;			 // modified or not
} APPT_ITEM, *LPAPPT_ITEM;

typedef struct _APPT_IMPORT_ITEM
{
    WORD wItemID;            // must be a unique index of the item to which this structure refers
    LPTSTR  pszText;         // pointer to a null-terminated string that contains the item text
    int  cchTextMax;         // number of characters in the buffer pointed to by pszText
    DATE dtStartDateTime;    // the date and time of the first occurrence of the appt
    ApptStatus nStatus;      // appointment status: 0=unused, 1=disarmed, 3=armed
    Frequency nFreq;         // frequency (or occurence) of the appt
    Reminder nReminder;      // reminder offset (used to calculate prenotification time)
    DATE dtReserved1;        // not used
    DATE dtReserved2;        // not used
	BYTE bModified;			 // modified or not
	LPTSTR  pszImportIDText; // pointer to a null-terminated string that contains the ID of the Import Item, as it pertains to the Add-In
	int  cchImportIDTextMax;    // number of characters in the buffer pointed to by pszImportIDText
} APPT_IMPORT_ITEM, *LPAPPT_IMPORT_ITEM;

// Occasion enumerations and item struct
enum OccasionType
{
	OCCASION_NONE     = 0,
	OCCASION_BDAY     = 1,
    OCCASION_ANNIV    = 2,
    OCCASION_HOLIDAY  = 3,
    OCCASION_VACATION = 4
};

typedef struct _OCCASION_ITEM
{
    WORD wItemID;            // must be a unique index of the item to which this structure refers
    LPTSTR  pszText;         // pointer to a null-terminated string that contains the item text
    int  cchTextMax;         // number of characters in the buffer pointed to by pszText
    DATE dtStartDateTime;    // the date and time of the original occurrence of the occasion
    BYTE bStatus;            // occasion status: 0=non-recurring, 1=recurring
    OccasionType nType;      // type of the occasion
	BOOL bIgnoreYear;		 // true if you want the occasion to not have the year specified
    DATE dtReserved1;        // not used
} OCCASION_ITEM, *LPOCCASION_ITEM;


typedef struct _PHONE_ITEM
{
    WORD wItemID;            // must be a unique index of the item to which this structure refers
    LPTSTR  pszNameText;     // pointer to a null-terminated string that contains the item text
    int  cchNameTextMax;     // number of characters in the buffer pointed to by pszText
    LPTSTR  pszTypeText;     // pointer to a null-terminated string that contains the item text, 2 chars max
    int  cchTypeTextMax;     // number of characters in the buffer pointed to by pszText
    LPTSTR  pszPhoneText;    // pointer to a null-terminated string that contains the item text
    int  cchPhoneTextMax;    // number of characters in the buffer pointed to by pszText
    BYTE bOptions;           // bit 0 = don't apply phone number formatting
                             // bit 1 = display left arrow in the first pos of the main dot matrix
                             // bit 2 = display right arrow at the end of the phone number
                             // bit 3 = display left arrow in the top dot matrix (in place of phone type)
} PHONE_ITEM, *LPPHONE_ITEM;

typedef struct _PHONE_IMPORT_ITEM

{
	LPTSTR  pszNameText;		// pointer to a null-terminated string that contains the name text
	int  cchNameTextMax;		// number of characters in the buffer pointed to by pszNameText
	LPTSTR  pszPhone1Text;    // pointer to a null-terminated string that contains the phone1 text
	int  cchPhone1TextMax;    // number of characters in the buffer pointed to by pszPhone1Text
	LPTSTR  pszPhone1TypeText;    
	int  cchPhone1TypeTextMax;

	LPTSTR  pszPhone2Text;    // pointer to a null-terminated string that contains the phone2 text
	int  cchPhone2TextMax;    // number of characters in the buffer pointed to by pszPhone2Text
	LPTSTR  pszPhone2TypeText;    
	int  cchPhone2TypeTextMax;
	
	LPTSTR  pszPhone3Text;    // pointer to a null-terminated string that contains the phone3 text
	int  cchPhone3TextMax;    // number of characters in the buffer pointed to by pszPhone3Text
	LPTSTR  pszPhone3TypeText;    
	int  cchPhone3TypeTextMax;

	LPTSTR  pszPhone4Text;    // pointer to a null-terminated string that contains the phone4 text
	int  cchPhone4TextMax;    // number of characters in the buffer pointed to by pszPhone4Text
	LPTSTR  pszPhone4TypeText;    
	int  cchPhone4TypeTextMax;

	LPTSTR  pszAddressText;    // pointer to a null-terminated string that contains the address text
	int  cchAdressTextMax;    // number of characters in the buffer pointed to by pszAddressText
	LPTSTR  pszEmailText;    // pointer to a null-terminated string that contains the Email text
	int  cchEmailTextMax;    // number of characters in the buffer pointed to by pszEmailText            
	LPTSTR  pszImportIDText; // pointer to a null-terminated string that contains the ID of the Import Item, as it pertains to the Add-In
	int  cchImportIDTextMax;    // number of characters in the buffer pointed to by pszImportIDText
	int	 iNumDupContacts;       // number indicating the number structures being imported related to this particular contact (Done when contact has more than 4 phone numbers), otherwise 1
	int  iImportIndex;			// number indicating the current index of the contact import related to iNumDupContacts
} PHONE_IMPORT_ITEM, *LPPHONE_IMPORT_ITEM;

// Note enumerations and item struct
typedef struct _NOTE_ITEM
{
    WORD wItemID;            // must be a unique index of the item to which this structure refers
    LPTSTR  pszText;         // pointer to a null-terminated string that contains the item text
    int  cchTextMax;         // number of characters in the buffer pointed to by pszText
    BYTE bStatus;            // note status: 0=unused, 1=used
	BYTE bModified;			 // modified or not
} NOTE_ITEM, *LPNOTE_ITEM;


// Note enumerations and item struct for Import Items
typedef struct _NOTE_IMPORT_ITEM
{
    WORD wItemID;            // must be a unique index of the item to which this structure refers
    LPTSTR  pszText;         // pointer to a null-terminated string that contains the item text
    int  cchTextMax;         // number of characters in the buffer pointed to by pszText
    BYTE bStatus;            // note status: 0=unused, 1=used
	BYTE bModified;			 // modified or not
	LPTSTR  pszImportIDText; // pointer to a null-terminated string that contains the ID of the Import Item, as it pertains to the Add-In
	int  cchImportIDTextMax;    // number of characters in the buffer pointed to by pszImportIDText
} NOTE_IMPORT_ITEM, *LPNOTE_IMPORT_ITEM;


// Options item struct
typedef struct _OPTION_ITEM
{
    BOOL boolNightModeEnabled;        // is nightmode enabled
    BOOL boolNightModeAuto;           // is nightmode auto on/off enabled
    BYTE bNightModeOnMin;             // the time night mode will be tured on on the device  
    BYTE bNightModeOnHour;
    BYTE bNightModeOffMin;            // the time night mode will be turned off on the device
    BYTE bNightModeOffHour;
    BYTE bNightModeToggleDuration;    // for how long the user needs to press the indiglo button to
                                      // turn on the nightmode; min=4, max=30
	//BYTE bNightModeDuration;          // how long the nightmode stays on, expressed in hours
    BOOL boolChimeEnabled;            // is hourly chime enabled
    BOOL boolChimeAuto;               // is hourly chime auto on/off enabled
    BYTE bChimeOnHour;                // the time chime will be turned on on the device
    BYTE bChimeOffHour;               // the time chime will be turned off on the device
    BOOL boolButtonBeepEnabled;       // is button beep enabled
    BYTE bLastSetCharacter;           // index to the last editable character during setting
    LPTSTR pszPassword;               // pointer to a null-terminated string that contains the password
    int  cchPasswordMax;              // number of characters in the buffer pointed to by pszPassword
    DWORD dwReserved;                 // not used
} OPTION_ITEM, *LPOPTION_ITEM;


// Sounds enumerations and item struct
enum SoundType
{
    SOUND_BUTTON_BEEP  = 0,
	SOUND_HOURLY_CHIME = 1,
	SOUND_ALARM        = 2,
	SOUND_APPOINTMENT  = 3,
	SOUND_TIMER        = 4,
	SOUND_INT_TIMER    = 5,
	SOUND_HALF_TIMER   = 6,
	SOUND_COMM_ERROR   = 7,
	SOUND_CUSTOM       = 8
};

typedef struct _SOUND_ITEM
{
    SoundType nItemID;       // must be a unique index of the item to which this structure refers
	int    nSoundsMax;       // number of bytes in the buffer pointed to by lpbSounds
	LPBYTE lpbSounds;        // pointer to an array of sounds - up to 16 bytes long
} SOUND_ITEM, *LPSOUND_ITEM;


enum GetItemType
{
    GETITEM_FIRST          = 0,
    GETITEM_NEXT           = 1,
    GETITEM_FIRST_MODIFIED = 2,
    GETITEM_NEXT_MODIFIED  = 3
};

// Interface routines
#ifdef __cplusplus
extern "C" {
#endif

////////////////////////////////////////////////////////////////////////////////
// 
//  int TUDLSetAppTitle(char *szTitle)
//
//  Purpose:    Allows you to create a custom application title
//				which is shown on the top of dialog boxes
//
//  Parameters: 
//              szTitle - null terminated string identifying the application title.
//
//  Returns:    0       Success
//              < 0     Error
//              > 0     Warning
//
////////////////////////////////////////////////////////////////////////////////
EXPORT32 int WINAPI TUDLSetAppTitle(char *szTitle);

////////////////////////////////////////////////////////////////////////////////
// 
//  int TUDLSetDeviceType(WORD wNewDeviceType)
//
//  Purpose:    Selects a new device to receive data (TUDL 100 watch,
//              TUDL 150 watch, etc.)
//
//  Parameters: 
//              wNewDeviceType - Indicator identifying the new device type.
//
//  Returns:    0       Success
//              < 0     Error
//              > 0     Warning
//
//  Note:       If the device type is invalid, will exit function immediately.
//
////////////////////////////////////////////////////////////////////////////////
EXPORT32 int WINAPI TUDLSetDeviceType(WORD wNewDeviceType);

////////////////////////////////////////////////////////////////////////////////
// 
//  int TUDLSetOption(WORD wSetWhat, DWORD dwToWhat, DWORD dwExtra)
//
//  Purpose:    Sets options for the DLL
//
//  Parameters: 
//              wSetWhat - What do you want to set.
//
//              dwToWhat - What you want it set to.
//
//  Returns:    0       Success
//              < 0     Error
//              > 0     Warning
//
////////////////////////////////////////////////////////////////////////////////
EXPORT32 int WINAPI TUDLSetOption(WORD wSetWhat, DWORD dwToWhat, DWORD dwExtra=0);

////////////////////////////////////////////////////////////////////////////////
// 
//  int TUDLGetOption(WORD wGetWhat, LPDWORD lpdwRetVal, DWORD dwExtra)
//
//  Purpose:    Sets options for the DLL
//
//  Parameters: 
//              wGetWhat - What value do you want to retrieve.
//
//              lpdwRetVal - Where do you want it to go.
//
//  Returns:    0       Success
//              < 0     Error
//              > 0     Warning
//
////////////////////////////////////////////////////////////////////////////////
EXPORT32 int WINAPI TUDLGetOption(WORD wGetWhat, LPDWORD lpdwRetVal, DWORD dwExtra=0);
    
////////////////////////////////////////////////////////////////////////////////
// 
//  int TUDLSendData(HWND hWnd)
//
//  Purpose:    Build the transmission file and send it out the selected port
//
//  Parameters: 
//              hWnd - handle to the parent window.
//
//  Returns:    0       Success
//              < 0     Error
//              > 0     Warning
//
////////////////////////////////////////////////////////////////////////////////
EXPORT32 int WINAPI TUDLSendData(HWND hWnd);

////////////////////////////////////////////////////////////////////////////////
// 
//  int TUDLGetData(HWND hWnd)
//
//  Purpose:    Build the transmission file and send it out the selected port
//
//  Parameters: 
//              hWnd - handle to the parent window.
//
//  Returns:    0       Success
//              < 0     Error
//              > 0     Warning
//
////////////////////////////////////////////////////////////////////////////////
EXPORT32 int WINAPI TUDLGetData(HWND hWnd);

////////////////////////////////////////////////////////////////////////////////
// 
//  int TUDLGetDeviceVersion(LPSTR lpszDevice1ID, WORD wDev1IDLen,
//                           LPSTR lpszDevice2ID, WORD wDev2IDLen)
//
//  Purpose:    Returns the IDs of the most recently connected device.
//
//  Parameters: 
//              lpszDevice1ID - pointer to a string to receive the main 
//              device ID.
//
//              wDev1IDLen - maximum number of characters to copy
//              into the string pointed-to by lpszDevice1ID.
//
//              lpszDevice2ID - pointer to a string to receive the secondary
//              device ID.
//
//              wDev2IDLen - maximum number of characters to copy
//              into the string pointed-to by lpszDevice2ID.
//
//              A NULL character ('/0') will always be installed in the last
//              character position.
//
//  Returns:    0       Success
//              < 0     Error
//              > 0     Warning
//
////////////////////////////////////////////////////////////////////////////////
EXPORT32 int WINAPI TUDLGetDeviceVersion(LPSTR lpszDevice1ID, WORD wDev1IDLen, 
								  LPSTR lpszDevice2ID, WORD wDev2IDLen);

////////////////////////////////////////////////////////////////////////////////
// 
//  int TUDLAddItem(AppIndex nAppIndex, BYTE bAppInstance, void* pItemStruct)
//
//  Purpose:    Adds an item
//
//  Parameters: nAppIndex - type of the item being added to the database
//
//              bAppInstance - instance of the application
//
//              pItemStruct - application specific item structure
//
//  Returns:    0       Success
//              > 0     Error
//              < 0     Warning
//
////////////////////////////////////////////////////////////////////////////////
EXPORT32 int WINAPI TUDLAddItem(AppIndex nAppIndex, BYTE bAppInstance, void* pItemStruct);

// Visual basic access functions since type libraries don't support void *'s
/*
EXPORT32 int WINAPI TUDLAddTODItem(BYTE bAppInstance, BYTE bItemID, LPCSTR pszText, int cchTextMax, LONG lTimeOffset, BYTE bTimeZoneID, 
								   TimeZoneIndex nTZIndex, TimeFormat nTimeFormat, DateFormat nDateFormat, BOOL boolDSTObserved,
								   BOOL boolIsInDST, BOOL boolShowWeekNumber, BYTE b1stDayOfWeek);

EXPORT32 int WINAPI TUDLAddChronoItem(BYTE bAppInstance, WORD wItemID, WORD wWorkoutID, BYTE bType, BYTE bNumLaps,
									  DATE dtDateTime, BYTE bLapNum, BYTE bHour, BYTE bMinute, BYTE bSecond, BYTE bHundredth);


EXPORT32 int WINAPI TUDLAddTimerItem(BYTE bAppInstance, WORD wItemID, LPCSTR pszText, int cchTextMax, BYTE bHour, BYTE bMinute,
									 BYTE bSecond, TimerAction nAction, BYTE bNumOfReps, BYTE bOptions);



EXPORT32 int WINAPI TUDLAddIntTimerItem(BYTE bAppInstance, WORD wItemID, LPCSTR pszText, int cchTextMax, BYTE bHour, BYTE bMinute,
										BYTE bSecond, TimerAction nAction, BYTE bNumOfReps, BYTE bOptions);

EXPORT32 int WINAPI TUDLAddAlarmItem(BYTE bAppInstance, WORD wItemID, LPCSTR pszText, int cchTextMax,
									 AlarmStatus nStatus, AlarmFrequency nFreq, BYTE bHour, BYTE bMinute,
									 DATE dtReserved1);


EXPORT32 int WINAPI TUDLAddApptItem(BYTE bAppInstance, WORD wItemID, LPCSTR  pszText, int  cchTextMax, DATE dtStartDateTime,
									ApptStatus nStatus, Frequency nFreq, Reminder nReminder, DATE dtReserved1, DATE dtReserved2);



EXPORT32 int WINAPI TUDLAddNoteItem(BYTE bAppInstance, WORD wItemID, LPCSTR pszText, int cchTextMax, BYTE bStatus);

EXPORT32 int WINAPI TUDLAddOptionItem(BYTE bAppInstance, BOOL boolNightModeEnabled, BOOL boolNightModeAuto, BYTE bNightModeOnMin,
									  BYTE bNightModeOnHour, BYTE bNightModeOffMin, BYTE bNightModeOffHour, BYTE bNightModeToggleDuration,
									  BOOL boolChimeEnabled, BOOL boolChimeAuto, BYTE bChimeOnHour, BYTE bChimeOffHour, BOOL boolButtonBeepEnabled,
									  BYTE bLastSetCharacter, LPCSTR pszPassword, int  cchPasswordMax, DWORD dwReserved);

EXPORT32 int WINAPI TUDLAddOccasionItem(BYTE bAppInstance, WORD wItemID, LPCSTR pszText, int cchTextMax, DATE dtStartDateTime,
										BYTE bStatus, OccasionType nType, BOOL bIgnoreYear, DATE dtReserved1);

EXPORT32 int WINAPI TUDLAddContactItem(BYTE bAppInstance, WORD wItemID, LPCSTR pszNameText, int cchNameTextMax, LPCSTR pszTypeText,
									   int  cchTypeTextMax, LPCSTR  pszPhoneText, int cchPhoneTextMax, BYTE bOptions);

EXPORT32 int WINAPI TUDLAddScheduleItem(BYTE bAppInstance, WORD wGroupID, LPCSTR  pszGroupText, int cchGroupTextMax, LPCSTR pszGroupLabel,
										int  cchGroupLabelMax, ScheduleType nType, WORD wItemID, LPCSTR pszText, int cchTextMax,
										DATE dtDateTime, int nDayOfWeek);

EXPORT32 int WINAPI TUDLAddSoundItem(BYTE bAppInstance, SoundType nItemID, int nSoundsMax, LPBYTE lpbSounds);
*/
EXPORT32 int WINAPI TUDLAddTODItem(int bAppInstance, int bItemID, char* pszText, int cchTextMax, long lTimeOffset, int bTimeZoneID, 
								   int nTZIndex, int nTimeFormat, int nDateFormat, int boolDSTObserved,
								   int boolIsInDST, int boolShowWeekNumber, int b1stDayOfWeek);

EXPORT32 int WINAPI TUDLAddChronoItem(int bAppInstance, int wItemID, int wWorkoutID, int bType, int bNumLaps,
									  DATE dtDateTime, int bLapNum, int bHour, int bMinute, int bSecond, int bHundredth);


EXPORT32 int WINAPI TUDLAddTimerItem(int bAppInstance, int wItemID, char* pszText, int cchTextMax, int bHour, int bMinute,
									 int bSecond, int nAction, int bNumOfReps, int bOptions);



EXPORT32 int WINAPI TUDLAddIntTimerItem(int bAppInstance, int wItemID, char* pszText, int cchTextMax, int bHour, int bMinute,
										int bSecond, int nAction, int bNumOfReps, int bOptions);

EXPORT32 int WINAPI TUDLAddAlarmItem(int bAppInstance, int wItemID, char* pszText, int cchTextMax,
									 int nStatus, int nFreq, int bHour, int bMinute,
									 DATE dtReserved1);


EXPORT32 int WINAPI TUDLAddApptItem(int bAppInstance, int wItemID, char* pszText, int cchTextMax, DATE dtStartDateTime,
									int nStatus, int nFreq, int nReminder, DATE dtReserved1, DATE dtReserved2);



EXPORT32 int WINAPI TUDLAddNoteItem(int bAppInstance, int wItemID, char* pszText, int cchTextMax, int bStatus);

EXPORT32 int WINAPI TUDLAddOptionItem(int bAppInstance, int boolNightModeEnabled, int boolNightModeAuto, int bNightModeOnMin,
									  int bNightModeOnHour, int bNightModeOffMin, int bNightModeOffHour, int bNightModeToggleDuration,
									  int boolChimeEnabled, int boolChimeAuto, int bChimeOnHour, int bChimeOffHour, int boolButtonBeepEnabled,
									  int bLastSetCharacter, char* pszPassword, int  cchPasswordMax, long dwReserved);

EXPORT32 int WINAPI TUDLAddOccasionItem(int bAppInstance, int wItemID, char* pszText, int cchTextMax, DATE dtStartDateTime,
										int bStatus, int nType, int bIgnoreYear, DATE dtReserved1);

EXPORT32 int WINAPI TUDLAddContactItem(int bAppInstance, int wItemID, char* pszNameText, int cchNameTextMax, char* pszTypeText,
									   int  cchTypeTextMax, char*  pszPhoneText, int cchPhoneTextMax, int bOptions);

EXPORT32 int WINAPI TUDLAddScheduleItem(int bAppInstance, int wGroupID, char* pszGroupText, int cchGroupTextMax, char* pszGroupLabel,
										int  cchGroupLabelMax, int nType, int wItemID, char* pszText, int cchTextMax,
										DATE dtDateTime, int nDayOfWeek);

EXPORT32 int WINAPI TUDLAddSoundItem(int bAppInstance, int nItemID, int nSoundsMax, LPBYTE lpbSounds);

////////////////////////////////////////////////////////////////////////////////
// 
//  int TUDLGetItem(AppIndex nAppIndex, BYTE bAppInstance, void* pItemStruct)
//
//  Purpose:    Adds an item
//
//  Parameters: nAppIndex - type of the item being added to the database
//
//              bAppInstance - instance of the application
//
//              pItemStruct - application specific item structure
//
//  Returns:    0       Success
//              > 0     Error
//              < 0     Warning
//
////////////////////////////////////////////////////////////////////////////////
EXPORT32 int WINAPI TUDLGetItem(AppIndex nAppIndex, BYTE bAppInstance, void* pItemStruct, 
                         GetItemType nItemType);

// Visual basic access functions since type libraries don't support void *'s
/*
EXPORT32 int WINAPI TUDLGetChronoItem(BYTE bAppInstance, LPWORD wItemID, LPWORD wWorkoutID, LPBYTE bType, LPBYTE bNumLaps,
									  DATE* dtDateTime, LPBYTE bLapNum, LPBYTE bHour, LPBYTE bMinute, LPBYTE bSecond, LPBYTE bHundredth, GetItemType nItemType);

EXPORT32 int WINAPI TUDLGetAlarmItem(int bAppInstance, int* wItemID, char** pszText, int *nStatus,
									 int *nFreq, int* bHour, int* bMinute, DATE* dtReserved1, int nItemType);

EXPORT32 int WINAPI TUDLGetApptItem(int bAppInstance, int* wItemID, char** pszText, DATE* dtStartDateTime,
									int* nStatus, int* nFreq, int* nReminder, DATE* dtReserved1, DATE* dtReserved2, int nItemType);

EXPORT32 int WINAPI TUDLGetNoteItem(BYTE bAppInstance, LPWORD wItemID, LPSTR* pszText, LPBYTE bStatus, GetItemType nItemType);
*/
EXPORT32 int WINAPI TUDLGetChronoItem(int bAppInstance, int* wItemID, int* wWorkoutID, int* bType, int* bNumLaps,
									  DATE* dtDateTime, int* bLapNum, int* bHour, int* bMinute, int* bSecond, int* bHundredth, BOOL *bModified, int nItemType);

EXPORT32 int WINAPI TUDLGetAlarmItem(int bAppInstance, int* wItemID, char** pszText, int *nStatus,
									 int *nFreq, int* bHour, int* bMinute, DATE* dtReserved1, BOOL *bModified, int nItemType);

EXPORT32 int WINAPI TUDLGetApptItem(int bAppInstance, int* wItemID, char** pszText, DATE* dtStartDateTime,
									int* nStatus, int* nFreq, int* nReminder, DATE* dtReserved1, DATE* dtReserved2, BOOL *bModified, int nItemType);

EXPORT32 int WINAPI TUDLGetNoteItem(int bAppInstance, int* wItemID, char** pszText, int* bStatus, BOOL *bModified, int nItemType);

EXPORT32 int WINAPI TUDLGetWristAppDB(int bAppInstance, DWORD *dwSize, BYTE* lpbDatabase);


////////////////////////////////////////////////////////////////////////////////
// 
//  int TUDLRemoveItem(AppIndex nAppIndex, BYTE bAppInstance, WORD wItemID)
//
//  Purpose:    Removes the item specified by the wItemID.
//
//  Parameters: nAppIndex...
//
//  Returns:    0       Success
//              < 0     Error
//              > 0     Warning
//
////////////////////////////////////////////////////////////////////////////////
EXPORT32 int WINAPI TUDLRemoveItem(AppIndex nAppIndex, BYTE bAppInstance, WORD wItemID);

////////////////////////////////////////////////////////////////////////////////
// 
//  int TUDLRemoveAllItems()
//
//  Purpose:    Frees all memory used by the appointments.  
//
//  Parameters: none
//
//  Returns:    0       Success
//              < 0     Error
//              > 0     Warning
//
////////////////////////////////////////////////////////////////////////////////
EXPORT32 int WINAPI TUDLRemoveAllItems(AppIndex nAppIndex, BYTE bAppInstance);

////////////////////////////////////////////////////////////////////////////////
// 
//  int TUDLRemoveAllApps()
//
//  Purpose:    Frees all applications
//
//  Parameters: none
//
//  Returns:    0       Success
//              < 0     Error
//              > 0     Warning
//
////////////////////////////////////////////////////////////////////////////////
EXPORT32 int WINAPI TUDLRemoveAllApps();

////////////////////////////////////////////////////////////////////////////////
// 
//  int TUDLAddApp(AppIndex nAppIndex, int nAppInstance, BOOL boolPassword,
//				   LPTSTR lpszModeName)
//
//  Purpose:    Adds an application ...
//
//  Parameters: 
//
//  Returns:    0       Success
//              < 0     Error
//              > 0     Warning
//
////////////////////////////////////////////////////////////////////////////////
EXPORT32 int WINAPI TUDLAddApp(AppIndex nAppIndex, int nAppInstance, BOOL boolPassword,
						LPTSTR lpszModeName);

////////////////////////////////////////////////////////////////////////////////
// 
//  int TUDLSetTimeLine(BOOL bTimeline1, BOOL bTimeline2)
//
//  Purpose:    Sets the timeline for the first two applications that support the timeline
//
//  Parameters: bTimeline1 - TRUE if the first timeline is set, FALSE otherwise
//				bTimeline2 - TRUE if the second timeline is set, FALSE otherwise
//
//  Returns:    0       Success
//              < 0     Error
//              > 0     Warning
//
////////////////////////////////////////////////////////////////////////////////
EXPORT32 int WINAPI TUDLSetTimeLine(BOOL bTimeline1, BOOL bTimeline2);

////////////////////////////////////////////////////////////////////////////////
// 
//  int TUDLResetDevice()
//
//  Purpose:    Send a reset sequence to the device after communication (writing)
//
//  Parameters: None
//
//  Returns:    0       Success
//              < 0     Error
//              > 0     Warning
//
////////////////////////////////////////////////////////////////////////////////
EXPORT32 int WINAPI TUDLResetDevice();

////////////////////////////////////////////////////////////////////////////////
// 
//  int TUDLSaveROMApps()
//
//  Purpose:    Prevents the ROM based apps from being erased before a download - factory use only
//
//  Parameters: None
//
//  Returns:    0       Success
//              < 0     Error
//              > 0     Warning
//
////////////////////////////////////////////////////////////////////////////////
EXPORT32 int WINAPI TUDLSaveROMApps();


////////////////////////////////////////////////////////////////////////////////
// 
//  int TUDLAddAppExt(AppIndex nAppIndex, int nAppInstance...)
//
//  Purpose:    Adds an application ...
//
//  Parameters: 
//
//  Returns:    0       Success
//              < 0     Error
//              > 0     Warning
//
////////////////////////////////////////////////////////////////////////////////
EXPORT32 int WINAPI TUDLAddAppExt(AppIndex nAppIndex, int nAppInstance, 
						   BOOL boolPassword, LPTSTR lpszModeName, 
						   LPBYTE lpbParam, BYTE bParamLen,
						   LPBYTE lpbCode, WORD wCodeLen,
						   LPBYTE lpbDatabase, WORD wDatabaseLen);

////////////////////////////////////////////////////////////////////////////////
// 
//  int TUDLAddPacket(LPBYTE lpData)
//
//  Purpose:    Adds a TUCP packet
//
//  Parameters: lpData - pointer to the packet to be downloaded, the packet
//                       must be properly formatted as there is no error
//                       checking done on the packet
//
//  Returns:    0       Success
//              < 0     Error
//              > 0     Warning
//
////////////////////////////////////////////////////////////////////////////////
EXPORT32 int WINAPI TUDLAddPacket(LPBYTE lpData);

////////////////////////////////////////////////////////////////////////////////
// 
//  int TUDLAddBinaryData(BYTE bMemoryType, DWORD dwAddress, DWORD dwSize, 
//                        LPBYTE lpData)
//
//  Purpose:    Adds a binary block of data to be downloaded
//
//  Parameters: bMemoryType - 0 for RAM, 1 for EEPROM
//              dwAddress - address where the data block will be placed
//              dwSize - number of bytes to be downloaded (maximum is 32k)
//              lpData - pointer to the block of binary data to be downloaded
//
//  Returns:    0       Success
//              < 0     Error
//              > 0     Warning
//
////////////////////////////////////////////////////////////////////////////////
EXPORT32 int WINAPI TUDLAddBinaryData(BYTE bMemoryType, DWORD dwAddress, DWORD dwSize,
                               LPBYTE lpData);

////////////////////////////////////////////////////////////////////////////////
// 
//  int TUDLAddPeriodicTask(WORD dwSize, LPBYTE lpData)
//
//  Purpose:    Adds a periodic task to be download
//
//  Parameters: wSize - number of bytes to be downloaded (maximum is 32k)
//              lpData - pointer to the block of binary data to be downloaded
//
//  Returns:    0       Success
//              < 0     Error
//              > 0     Warning
//
////////////////////////////////////////////////////////////////////////////////
EXPORT32 int WINAPI TUDLAddPeriodicTask(WORD dwSize, LPBYTE lpData);

////////////////////////////////////////////////////////////////////////////////
// 
//  int TUDLRemovePeriodicTask()
//
//  Purpose:    Resets the watch so that no periodic tasks are present
//
//  Parameters: None
//
//  Returns:    0       Success
//              < 0     Error
//              > 0     Warning
//
////////////////////////////////////////////////////////////////////////////////
EXPORT32 int WINAPI TUDLRemovePeriodicTask();

////////////////////////////////////////////////////////////////////////////////
// 
//  int TUDLRequestBinaryData(BYTE bMemoryType, DWORD dwAddress, DWORD dwSize)
//
//  Purpose:    Adds a binary block of data to be downloaded
//
//  Parameters: bMemoryType - 0 for RAM, 1 for EEPROM
//              dwAddress - address where the data block will be placed
//              dwSize - number of bytes to be downloaded (maximum is 32k)
//
//  Returns:    0       Success
//              < 0     Error
//              > 0     Warning
//
////////////////////////////////////////////////////////////////////////////////
EXPORT32 int WINAPI TUDLRequestBinaryData(BYTE bMemoryType, DWORD dwAddress, DWORD dwSize);
    
////////////////////////////////////////////////////////////////////////////////
// 
//  int TUDLGetBinaryData(BYTE bMemoryType, DWORD dwAddress, DWORD dwSize, 
//                        LPBYTE lpData)
//
//  Purpose:    Adds a binary block of data to be downloaded
//
//  Parameters: bMemoryType - 0 for RAM, 1 for EEPROM
//              dwAddress - address where the data block will be placed
//              dwSize - number of bytes to be downloaded (maximum is 32k)
//              lpData - pointer to the block of binary data to be downloaded
//
//  Returns:    0       Success
//              < 0     Error
//              > 0     Warning
//
////////////////////////////////////////////////////////////////////////////////
EXPORT32 int WINAPI TUDLGetBinaryData(BYTE bMemoryType, DWORD dwAddress, DWORD dwSize,
                               LPBYTE lpData);

////////////////////////////////////////////////////////////////////////////////
// 
//  int TUDLReleaseChrono()
//
//  Purpose:    Frees all memory used by the chronograph.
//
//  Parameters: none
//
//  Returns:    0       Success
//              < 0     Error
//              > 0     Warning
//
////////////////////////////////////////////////////////////////////////////////
EXPORT32 int WINAPI TUDLReleaseChrono();

////////////////////////////////////////////////////////////////////////////////
// 
//  int TUDLReleaseAllBinaryData()
//
//  Purpose:    To release resources used by binary data.
//
//  Parameters: none
//
//  Returns:    0       Success
//              > 0     Error Code
//              < 0     Warning Code
//
////////////////////////////////////////////////////////////////////////////////
EXPORT32 int WINAPI TUDLRemoveAllBinaryData();

////////////////////////////////////////////////////////////////////////////////
// 
//  int TUDLRemoveAllBinaryIntData()
//
//  Purpose:    To release resources used by internal binary data.
//
//  Parameters: none
//
//  Returns:    0       Success
//              > 0     Error Code
//              < 0     Warning Code
//
////////////////////////////////////////////////////////////////////////////////
EXPORT32 int WINAPI TUDLRemoveAllBinaryIntData();

////////////////////////////////////////////////////////////////////////////////
// 
//  int TUDLRemoveAllRequestBinaryData()
//
//  Purpose:    To release resources used by binary data.
//
//  Parameters: none
//
//  Returns:    0       Success
//              > 0     Error Code
//              < 0     Warning Code
//
////////////////////////////////////////////////////////////////////////////////
EXPORT32 int WINAPI TUDLRemoveAllRequestBinaryData();

////////////////////////////////////////////////////////////////////////////////
// 
//  int TUDLRemoveAllPackets()
//
//  Purpose:    To release memory used by the individual packets
//
//  Parameters: none
//
//  Returns:    0       Success
//              < 0     Error
//              > 0     Warning
//
////////////////////////////////////////////////////////////////////////////////
EXPORT32 int WINAPI TUDLRemoveAllPackets();

////////////////////////////////////////////////////////////////////////////////
// 
//  int TUDLShowDialog(BOOL bShow)
//
//  Purpose:    Shows or hides the progress dialog
//
//  Parameters: bShow - TRUE to show the dialog, FALSE to hide the dialog
//
//  Returns:    0       Success.....
//              < 0     Error: Check wErrCode.
//              > 0     Warning: Check wWrnCode.
//
////////////////////////////////////////////////////////////////////////////////
EXPORT32 int WINAPI TUDLShowDialog(BOOL bShow);

////////////////////////////////////////////////////////////////////////////////
// 
//  int TUDLForceFullDownload()
//
//  Purpose:    Call this function before sending to force a full download and turn
//				off the partial download feature
//
//  Parameters: none
//
//  Returns:    0       Success.....
//              < 0     Error: Check wErrCode.
//              > 0     Warning: Check wWrnCode.
//
////////////////////////////////////////////////////////////////////////////////
EXPORT32 int WINAPI TUDLForceFullDownload();

////////////////////////////////////////////////////////////////////////////////
//
//  int TUDLBeep(WORD wFrequency, WORD wDuration)
//
//  Purpose:    To produce a sound (beep) through the PC speaker of a given 
//              frequency and duration
//
//  Parameters: 
//              wFrequency - The frequency of the sound in Hz from 37 to 32767 
//              wDuration - The duration of the sound in msec from 75 up
//
//  Returns:    TRUE (!0) Always
//
////////////////////////////////////////////////////////////////////////////////
EXPORT32 int WINAPI TUDLBeep(WORD wFrequency, WORD wDuration);

////////////////////////////////////////////////////////////////////////////////
//
//  BYTE TUDLCalculateChecksum(LPBYTE lpBuffer, WORD wBufferLength)
//
//  Purpose:    To calculate checksum for the data stored in the buffer
//
//  Parameters: lpBuffer - The pointer to the buffer array
//              wBufferLength - The length of the buffer
//
//  Returns:    Checksum value as BYTE type
//
////////////////////////////////////////////////////////////////////////////////
EXPORT32 BYTE WINAPI TUDLCalculateChecksum(LPBYTE lpBuffer, WORD wBufferLength);

////////////////////////////////////////////////////////////////////////////////
//
//  BOOL TUDLVerifyChecksum(LPBYTE lpBuffer, WORD wBufferLength)
//
//  Purpose:    To verify checksum for the data stored in the buffer
//
//  Parameters: lpBuffer - The pointer to the buffer array
//              wBufferLength - The length of the buffer
//
//  Returns:    TRUE if checksum is valid, FALSE if checksum is invalid
//
////////////////////////////////////////////////////////////////////////////////
EXPORT32 BOOL WINAPI TUDLVerifyChecksum(LPBYTE lpBuffer, WORD wBufferLength);


#ifdef __cplusplus
}
#endif

#endif // __TUCP_H__
